@@ -15,6 +15,8 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */
+#include <config.h>
+
 #include <stdio.h>
 #include <ctype.h>
 #include <stdlib.h>
@@ -186,7 +188,7 @@ get_map_real_coord (loc)
 	 game_map.height minus one and rightmost point is
 	 game_map.width minus one.  */
       if (loc->x < 0 || loc->x >= game_map.width
-	  || loc->y < 0 || loc->x >= game_map.height)
+	  || loc->y < 0 || loc->y >= game_map.height)
 	{
 	  loc->x = -1;
 	  loc->y = -1;
@@ -512,3 +514,50 @@ dist_to_capital (player, loc)
      comparisons.  */
   return x_dist*x_dist + y_dist*y_dist;
 }
+
+extern char
+need_update ()
+{
+  /* Need not to be thread-safe.  */
+  static char last_modes, last_attacks, last_turn;
+  register char update = 0;
+
+  /* A situation where no modes are available is impossible.  */
+  if (last_modes == 0)
+    {
+      last_modes = ~game_map.modes;
+      last_attacks = game_map.n_att;
+      last_turn = game_map.turn - 1;
+    }
+
+  if (game_map.modes & MODE_ATT)
+    {
+      if (!(last_modes & MODE_ATT))
+	{
+	  update = MODE_ATT;
+	  last_attacks = game_map.n_att;
+	}
+      else if (game_map.n_att != last_attacks)
+	{
+	  update = MODE_ATT;
+	  last_attacks = game_map.n_att;
+	}
+    }
+  else if ((last_modes & MODE_ATT) && !(game_map.modes & MODE_ATT))
+    update = MODE_ATT;
+
+  /* xor */
+  if (!(game_map.modes & MODE_DEF) != !(last_modes & MODE_DEF))
+    update |= MODE_DEF;
+  if (!(game_map.modes & MODE_GUE) != !(last_modes & MODE_GUE))
+    update |= MODE_GUE;
+
+  if (game_map.turn != last_turn)
+    {
+      update |= UPDATE_TURN;
+      last_turn = game_map.turn;
+    }
+
+  last_modes = game_map.modes;
+  return update;
+}
