@@ -19,17 +19,17 @@
 
 #define _MAP_H 1
 
-#define MASK_PLAYER 31
-#define MASK_PLAIN 63
-#define MASK_OCCUPIED 32
-#define MASK_CAPITAL 64
-#define MASK_CROSS 128
+#define MASK_PLAYER	31
+#define MASK_PLAIN	63
+#define MASK_OCCUPIED	32
+#define MASK_CAPITAL	64
+#define MASK_CROSS	128
 #define SEA_VAL 0
 #define CROSS_MAX 6
-#define MODE_ATT 1
-#define MODE_DEF 2
-#define MODE_GUE 4
-
+#define MODE_ATT	1
+#define MODE_DEF	2
+#define MODE_GUE	4
+#define UPDATE_TURN	8
 
 /* A hell will propably break loose if this is changed.  */
 #define MAXPLAYERS 2
@@ -110,5 +110,6 @@ extern void set_map_bit (Coord, map_val);
 extern enum cross_act check_cross (Coord);
 extern int toggle_cross (Coord);
 extern int dist_to_capital (int, Coord);
+extern char need_update (void);
 
 #endif /* map.h  */
