@@ -25,15 +25,15 @@ enum motti_errors {
   ERR_NONAME,		/* A map file wasn't found.  */
   ERR_INVNAME,		/* Invalid map file.  */
   ERR_NOX,		/* Can't open display.  */
-  /* Note to myself: failed malloc shouldn't be fatal!  */
+  /* Note to myself: failed malloc shouldn't be fatal?  Motti uses so
+     little memory, that this might not be a problem at all.  */
   ERR_MALLOC,		/* Can't alloc memory.  */
-  /* Note to myself: hardcode defaults, as a last resort.  */
   ERR_COLOR_FIND,       /* Can't find a color value.  */
   ERR_COLOR_ALLOC       /* Can't allocate a color value.  */
 };
 
 extern void die (char *);
-extern char *alloc_err_str (enum motti_errors, char *);
+extern char *alloc_err_str (enum motti_errors, const char *);
 extern void *my_malloc (size_t);
 extern void *my_calloc (size_t, size_t);
 
