@@ -15,6 +15,10 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */
+#include <config.h>
+
+#ifdef HAVE_LIBX11
+
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 
@@ -33,10 +37,6 @@ extern int screen_num;
 extern void
 event_loop ()
 {
-  char last_modes, last_attacks;
-  last_modes = 0;
-  last_attacks = game_map.n_att;
-
   XSelectInput (display, main_win, 0);
   XSelectInput (display, but_win[ATT], ButtonPressMask);
   XSelectInput (display, but_win[DEF], ButtonPressMask);
@@ -48,7 +48,7 @@ event_loop ()
   XMapWindow (display, but_win[DEF]);
   XMapWindow (display, but_win[GUE]);
   XMapWindow (display, main_win);
-  update_buttons (&last_modes, &last_attacks);
+  update_buttons ();
 
   while (1)
     {
@@ -90,8 +90,9 @@ event_loop ()
 	      if (toggle_cross (coord))
 		draw_map (report.xbutton.x, report.xbutton.y, 0, 0);
 	    }
-	  update_buttons (&last_modes, &last_attacks);
+	  update_buttons ();
 	  break;
 	}
     }
 }
+#endif /* have_libx11 */
