@@ -15,6 +15,10 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */
+#include <config.h>
+
+#ifdef HAVE_LIBX11
+
 /* This file has general X init routines. The O'Reilly's Xlib
    Programming manual by Adrian Nye has been used as a guide.  */
 
@@ -25,8 +29,15 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
+#ifdef HAVE_STRING_H
+# include <string.h>
+#else
+# include <strings.h>
+#endif
+
+#ifdef HAVE_GETHOSTNAME
+# include <unistd.h>
+#endif
 
 #include "xwin.h"
 #include "map.h"
@@ -58,7 +69,8 @@ static Visual *visual;
 static GC tempgc;
 
 static void init_DB_tab (void);
-static int alloc_Xrm_color (char *, char *, char *, XColor *);
+static int alloc_Xrm_color (const char *, const char *, const char *,
+			    XColor *);
 static void make_map_stipples (Pixmap, Pixmap, int, int);
 static void make_att_buttons (void);
 static void make_att_pixs (void);
@@ -72,43 +84,77 @@ init_DB_tab ()
 {
   register int i;
 
-  enum types
+  enum types 
   {
     type_short,
+    type_string,
     end
   };
   struct val_tab
   {
-    enum types type;
-    short *ptr;
-    char *name, *class;
-    int deflt;
+    const enum types type;
+    void *ptr;
+    const char *name, *class;
+    union
+    {
+      const int val;
+      const char *str;
+    } def;
   };
-  struct val_tab vals[3] =
+  struct val_tab vals[] =
   {
     {type_short, &db_val_tab.but_width, "motti.button.width",
      "Motti.Button.Width", 80},
     {type_short, &db_val_tab.but_height, "motti.button.height",
      "Motti.Button.Height", 20},
+    {type_string, &db_val_tab.geom_str, "motti.geometry",
+     "Motti.Geometry", 0},
     {end, NULL, "", "", 0}
   };
+  struct val_tab *val_ptr = vals;
+  vals[2].def.str = "1x1";
 
-  for (i = 0; vals[i].type != end; i++)
+  while (val_ptr->type != end)
     {
       char *str_type;
       XrmValue value;
-      if (XrmGetResource (DB, vals[i].name, vals[i].class, &str_type,
+      if (XrmGetResource (DB, val_ptr->name, val_ptr->class, &str_type,
 			  &value))
 	{
-	  switch (vals->type)
+	  switch (val_ptr->type)
 	    {
+	      char *str;
 	    case type_short:
-	      *(vals[i].ptr) = (short) atoi (value.addr);
+	      *((short *) val_ptr->ptr) = (short) atoi (value.addr);
+	      break;
+	    case type_string:
+	      str = (char *) my_malloc ((strlen (value.addr)+1) *
+					 sizeof (char));
+	      strcpy (str, value.addr);
+	      *((char **) val_ptr->ptr) = str;
+	      break;
 	    case end:
 	    }
 	}
       else
-	*(vals[i].ptr) = (short) vals->deflt;
+	{
+	  switch (val_ptr->type)
+	    {
+	    case type_short:
+	      *((short *) val_ptr->ptr) = (short) val_ptr->def.val;
+	      goto hardcoded;
+	      break;
+	    case type_string:
+	      *((const char **) val_ptr->ptr) = val_ptr->def.str;
+	      goto hardcoded;
+	      break;
+	    case end:
+	      break;
+	    hardcoded:
+	      fprintf (stderr, "motti: using hard-coded default resource value for %s\n", val_ptr->name);
+	    }
+	}
+      val_ptr++;
     }
 }
 
@@ -127,8 +173,7 @@ open_display (display_name)
   else
     {
       XrmCombineFileDatabase ("~/.Xdefaults", &displayDB, False);
-      XrmCombineFileDatabase ("/usr/lib/X11/app-defaults/Motti",
-			      &displayDB, False);
+      XrmCombineFileDatabase (APPDEF, &displayDB, False);
       if (XrmGetResource (displayDB, "motti.display",
 			  "Motti.Display", &str_type, &value))
 	display = XOpenDisplay (value.addr);
@@ -149,7 +194,7 @@ open_display (display_name)
 extern void
 create_DB ()
 {
-  char filename[1024] = "/usr/lib/X11/app-defaults/Motti";
+  char filename[1024] = APPDEF;
   char *environment;
 
   /* First get the application defaults.  */
@@ -185,11 +230,12 @@ create_DB ()
 
 static int
 alloc_Xrm_color (instance, class, deflt, color)
-     char *instance, *class;
-     char *deflt;
+     const char *instance, *class;
+     const char *deflt;
      XColor *color;
 {
-  char *msg = NULL, *color_name;
+  char *msg = NULL;
+  const char *color_name;
   XrmValue value;
   XColor nullcol;
   char *str_type;
@@ -199,7 +245,11 @@ alloc_Xrm_color (instance, class, deflt, color)
   else
     {
       if (deflt)
-	color_name = deflt;
+	{
+	  color_name = deflt;
+	  fprintf (stderr, "motti: using hard-coded default color %s for %s\n",
+		   deflt, instance);
+	}
       else
 	msg = alloc_err_str (ERR_COLOR_FIND, class);
     }
@@ -264,20 +314,30 @@ alloc_colors ()
 			    &misc_col[but_bg])))
     return 0;
 
+#define MAXDEFCOLPLAYER 2
   for (i = 1; i <= players; i++)
     {
-      char instancename[256];
+      const char *def_col[] =
+      {
+	"RGBi:0.4/0/0", "RGBi:1.0/0/0",
+	"RGBi:0/0/0.4", "RGBi:0/0/1.0",
+	""
+      };
+      char instancename[25];
       sprintf (instancename, "motti.player%i.color", i);
-      if (!alloc_Xrm_color (instancename, "Motti.Player.Color", "",
-			  &player_col[i-1]))
+      if (!alloc_Xrm_color (instancename, "Motti.Player.Color",
+			    def_col[i <= MAXDEFCOLPLAYER ? (i-1)*2 :
+				   4], &player_col[i-1]))
 	return 0;
 
       sprintf (instancename, "motti.player%iOcc.color", i);
-      if (!alloc_Xrm_color (instancename, "Motti.PlayerOcc.Color", "",
-			   &occupied_col[i-1]))
+      if (!alloc_Xrm_color (instancename, "Motti.PlayerOcc.Color",
+			    def_col[i <= MAXDEFCOLPLAYER ? (i-1)*2+1 :
+				   4], &occupied_col[i-1]))
 	return 0;
     }
   return 1;
+#undef MAXDEFCOLPLAYER
 }
 
 static void
@@ -528,11 +588,9 @@ set_hints (min_width, min_height, argv, argc)
   XClassHint *class_hints;
   XTextProperty window_name_prop, icon_name_prop;
   /* Add version number.  */
-  char name_vers[12] = "motti ";
-  char *window_name = name_vers;
+  char *window_name = VERSION_STR;
   char *icon_name = "motti";
   XSizeHints *size_hints;
-  snprintf (&name_vers[6], 6, "%s", VERSION);
 
   if (!XStringListToTextProperty (&window_name, 1, &window_name_prop)
       || !XStringListToTextProperty (&icon_name, 1, &icon_name_prop))
@@ -588,17 +646,6 @@ open_windows (argc, argv)
     }
   XParseGeometry (db_val_tab.geom_str, &x, &y, &width, &height);
 
-  if (XrmGetResource (DB, "Motti.Button.Width",
-		      "motti.button.width", &str_type, &value))
-    db_val_tab.but_width = atoi (value.addr);
-  else
-    db_val_tab.but_width = 80;
-  if (XrmGetResource (DB, "Motti.Button.Height",
-		      "motti.button.height", &str_type, &value))
-    db_val_tab.but_height = atoi (value.addr);
-  else
-    db_val_tab.but_height = 20;
-
   win_attribs.background_pixel = misc_col[bg_col].pixel;
   main_win = XCreateWindow (display, RootWindow(display, screen_num),
 			    x, y, width, height, 0, CopyFromParent,
@@ -649,7 +696,7 @@ open_windows (argc, argv)
 			   | CWBackPixel, &win_attribs);
 
   set_hints (x + game_map.width * MAPSQUARESIZE + 2 * X_MARGIN, y +
-	     MINMAPHEIGHT*MAPSQUARESIZE + Y_MARGIN, argv, argc);
+	     game_map.height * MAPSQUARESIZE + Y_MARGIN, argv, argc);
 }
 
 #include "bitmaps/map_pointer_active"
@@ -703,3 +750,5 @@ kill_x ()
 {
   XCloseDisplay (display);
 }
+
+#endif /* have_libx11 */
