@@ -37,7 +37,7 @@ enum button_class {
   ATT, DEF, GUE
 };
 
-extern void update_buttons (char *, char *);
+extern void update_buttons (void);
 extern void draw_map (int, int, int, int);
 extern void draw_effects (Action);
 extern Coord win_pos2map_coord (int, int);
